import lodash from 'lodash'
import { Context as ContextRegistry } from 'skypager-registry'
import { hideProperty, lazy, strings, mixinPropertyUtils } from 'skypager-util'
import attachEmitter from './utils/emitter'

const { camelize, underscore, singularize, pluralize } = strings

require.ensure([], () => {
  Helper.modules = new ContextRegistry('helpers', { context: require.context('./helpers', false, /((?!spec).{4}|^.{0,3})\.js$/) })
})

export const requireContext = require.context('./helpers', false, /((?!spec).{4}|^.{0,3})\.js$/)

export class Helper {
  static isCacheable = true

  static cacheable(setting = true) {
    return this.isCacheable = !!setting
  }

  static requireContext = requireContext

  static attach (host, helperClass = Helper, options = {}) {
    return attach(host, helperClass, options)
  }

  static createRegistry = () => (
    Helper.modules || new ContextRegistry('helpers', { context: require.context('./helpers', false, /((?!spec).{4}|^.{0,3})\.js$/) })
  )

  isInitialized = false
  isConfigured = false

  constructor(options = {}, context = {}) {
    mixinPropertyUtils(this)
    attachEmitter(this)

    this.hide('context', context)
    this.hide('project', context.project)
    this.hideGetter('options', () => lodash.omit(options, 'provider'))
    this.getter('provider', () => options.provider)

    this.name = options.provider.name || options.id
    this.id = [this.get('project.id', this.constructor.name), this.name, Math.floor(new Date() / 100)].join(':')

    if (options.initialize !== false) {
      this.doInitialize()
    }
  }

  get initialized() {
    this.doInitialize()
    return this
  }

  doInitialize() {
    this.isInitialized = !!this.result('initialize', () => true)

    if (this.configure && this.options.configure) {
      this.configure(this.options.configure)
    }
  }

  get chain() {
    return lodash.chain(this)
  }
}

export default Helper

export const attach = (host, helperClass, options = {}) => {
  const {
    registryProp = camelize(pluralize(underscore(helperClass.name))).toLowerCase(),
    lookupProp = singularize(camelize(underscore(helperClass.name))).toLowerCase(),
  } = options

  if (host[registryProp]) {
    return host
  }

  lazy(host, registryProp, () => options.registry || helperClass.createRegistry())

  hideProperty(host, lookupProp, (name, opts = {}, ctx = {}) => {
    const reg = host[registryProp]

    const {
      cacheHelper = !!(helperClass.isCacheable || opts.cacheHelper)
    } = opts

    if (!cacheHelper) {
      return new helperClass({
        ...opts,
        provider: reg.lookup(name),
        id: name,
      }, {
        ...host.createSandbox(),
        host,
        reg
      })
    } else {
      return host.cache.fetch(`${host.instanceId}:${lookupProp}:${name}`, () => (
        new helperClass({...opts, provider: reg.lookup(name), id: name, }, {
          ...host.createSandbox(ctx),
          host,
          reg
        })
      ))
    }
  })

  return host
}
